package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````8!,``#0```"4D0````0`!30`(``*
M`"@`&P`:``$``'"0AP``D(<``)"'```(````"`````0````$````!@```#0`
M```T````-````$`!``!``0``!`````0````#````F`$``)@!``"8`0``&0``
M`!D````$`````0````$```````````````````"\AP``O(<```4`````$```
M`0```+R-``"\G0``O)T``(P"``"@`@``!@`````0```"````Q(T``,2=``#$
MG0``"`$```@!```&````!`````0```!T`0``=`$``'0!```D````)`````0`
M```$````!````)R'``"<AP``G(<``"`````@````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&2\C0``O)T``+R=``!$`@``
M1`(```0````!````!````!0````#````1TY5`#3W04LQN*GP*$+5MU88\&R*
M=PI=+VQI8B]L9"UL:6YU>"UA<FUH9BYS;RXS``````$````!`````0``````
M````````````````````````````````````````H`T````````#``H`````
M``"@`````````P`6`!("`````````````!(```!Q```````````````2````
MZ@(`````````````$@```+4"`````````````!(```"G`@`````````````2
M````>P``````````````$@```(H!`````````````!(```"'````````````
M```2`````0``````````````(````*`"`````````````!(```"Y````````
M```````2````80``````````````$@```*X"`````````````!(```#G````
M```````````2````U`$`````````````$@```!```````````````"````#<
M```````````````2````O0(`````````````$@```'8``````````````!(`
M`````@`````````````2````Q`(`````````````$@```"P`````````````
M`"````!J`@`````````````2````!0(`````````````$@```%,`````````
M`````!(````G`0`````````````6````!`$`````````````$@```&H!````
M`````````!(```"H```````````````2````]0``````````````$@```/,!
M`````````````!(```#<`0`````````````2````RP(`````````````$@``
M`.H!`````````````!(```#-```````````````2````^@(`````````````
M$0```,T!`````````````!(````4`P`````````````1````&`(`````````
M````$@```)H``````````````!(```#$`0`````````````2````O0$`````
M````````$@```%X!`````````````!(```"K`0`````````````2````(`$`
M````````````$@```)4!`````````````!(```!;`@`````````````2````
MXP$`````````````$@```/H!`````````````!(```!I`@`````````````2
M`````@,`````````````$@```#H!`````````````!(````G`@``````````
M```2````%`$`````````````$@```"X"`````````````!(```#X`@``````
M```````1````@P(`````````````$0```$8``````````````!$```"S`0``
M```````````2````3P$`````````````$0```#\"`````````````!(```#P
M`@`````````````2````P@``````````````$@```$T"`````````````!(`
M```W`@`````````````2````>P$`````````````$@```'$"````````````
M`!(```"*`@`````````````2````T@(`````````````$@```*8!````````
M`````!(```#9`@`````````````2````D0(`````````````(@````!?7V=M
M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U;F1U;7``4&5R;%]S>7-?=&5R
M;0!097)L7V=V7V9E=&-H<'8`<&5R;%]F<F5E`%!E<FQ?9V5T7W-V`%!E<FQ?
M871F;W)K7W5N;&]C:P!P97)L7V1E<W1R=6-T`%!E<FQ?;F5W6%-?9FQA9W,`
M<&5R;%]R=6X`4&5R;%]N97=84P!097)L7W-V7W-E='!V;@!P97)L7V%L;&]C
M`%!E<FQ?<W9?<V5T<'8`<&5R;%]C;VYS=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4$Q?;65M;W)Y7W=R87``4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?;&]C:P!097)L7W-Y<U]I;FET,P!P97)L7W!A<G-E`%]?<W1A
M8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO
M<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!G971P=W5I9`!S
M=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`;6MD:7(`7U]V9G!R:6YT
M9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?
M7VUE;6UO=F5?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A
M<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M
M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R
M8VUP`%]?97)R;F]?;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS
M;RXU+C0P`&QI8F,N<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`$=,24)#7S(N
M-`!'3$E"0U\R+C,T`$=,24)#7S(N,S,``````````@`!``(``@`"``$``0`!
M``$``@`!``$``@`!``(``0`!``(``@`"``(``0`#``(``0`!``$``0`!``$`
M`@`"``(``@`!``(``@`$``(``0`"``(``0`"``(``@`"``(``@`#``(``0`"
M``$``@`"``(``0`"``$``@`"``$``@`"``$`!0`"``(``@`"``(````!``$`
M0`,``!`````@````%&EI#0``!`!4`P````````$``P`V`P``$`````````"T
MD98&```%`%X#```0````LY&6!@```P!I`P``$````!1I:0T```(`5`,`````
M``"\G0``%P```,"=```7````_)\``!<````$H```%P```!2@```7````&*``
M`!<````@H```%P```"2@```7````**```!<````LH```%P```#"@```7````
M.*```!<````\H```%P```$2@```7````R)\``!4*``#,GP``%0L``-"?```5
M$@``U)\``!48``#8GP``$QP``-R?```5'0``X)\``!4>``#DGP``%28``.B?
M```5*```[)\``!4[``#PGP``%3P``/2?```5/@``^)\``!5*``#8G@``%@,`
M`-R>```6!```X)X``!8%``#DG@``%@8``.B>```6!P``[)X``!8(``#PG@``
M%@D``/2>```6"P``^)X``!8,``#\G@``%@T```"?```6#@``!)\``!8/```(
MGP``%A````R?```6$0``$)\``!83```4GP``%A0``!B?```6%0``')\``!86
M```@GP``%A<``"2?```6&0``*)\``!8:```LGP``%AL``#"?```6'P``-)\`
M`!8@```XGP``%B$``#R?```6(@``0)\``!8C``!$GP``%B0``$B?```6)0``
M3)\``!8G``!0GP``%BD``%2?```6*@``6)\``!8K``!<GP``%BP``&"?```6
M+0``9)\``!8N``!HGP``%B\``&R?```6,```<)\``!8Q``!TGP``%C(``'B?
M```6,P``?)\``!8T``"`GP``%C4``(2?```6-@``B)\``!8W``",GP``%C@`
M`)"?```6.0``E)\``!8]``"8GP``%C\``)R?```60```H)\``!9!``"DGP``
M%D(``*B?```60P``K)\``!9$``"PGP``%D4``+2?```61@``N)\``!9'``"\
MGP``%D@``,"?```620``Q)\``!9*```(0"WI?@$`ZPB`O>@$X"WE!."?Y0[@
MC^`(\+[E$)$```#&C^()RHSB$/&\Y0#&C^()RHSB"/&\Y0#&C^()RHSB`/&\
MY0#&C^()RHSB^/"\Y0#&C^()RHSB\/"\Y0#&C^()RHSBZ/"\Y0#&C^()RHSB
MX/"\Y0#&C^()RHSBV/"\Y0#&C^()RHSBT/"\Y0#&C^()RHSBR/"\Y0#&C^()
MRHSBP/"\Y0#&C^()RHSBN/"\Y0#&C^()RHSBL/"\Y0#&C^()RHSBJ/"\Y0#&
MC^()RHSBH/"\Y0#&C^()RHSBF/"\Y0#&C^()RHSBD/"\Y0#&C^()RHSBB/"\
MY0#&C^()RHSB@/"\Y0#&C^()RHSB>/"\Y0#&C^()RHSB</"\Y0#&C^()RHSB
M:/"\Y0#&C^()RHSB8/"\Y0#&C^()RHSB6/"\Y0#&C^()RHSB4/"\Y0#&C^()
MRHSB2/"\Y0#&C^()RHSB0/"\Y0#&C^()RHSB./"\Y0#&C^()RHSB,/"\Y0#&
MC^()RHSB*/"\Y0#&C^()RHSB(/"\Y0#&C^()RHSB&/"\Y0#&C^()RHSB$/"\
MY0#&C^()RHSB"/"\Y0#&C^()RHSB`/"\Y0#&C^((RHSB^/^\Y0#&C^((RHSB
M\/^\Y0#&C^((RHSBZ/^\Y0#&C^((RHSBX/^\Y0#&C^((RHSBV/^\Y0#&C^((
MRHSBT/^\Y0#&C^((RHSBR/^\Y0#&C^((RHSBP/^\Y0#&C^((RHSBN/^\Y0#&
MC^((RHSBL/^\Y0#&C^((RHSBJ/^\Y0#&C^((RHSBH/^\Y0#&C^((RHSBF/^\
MY0#&C^((RHSBD/^\Y0#&C^((RHSBB/^\Y0#&C^((RHSB@/^\Y0#&C^((RHSB
M>/^\Y0#&C^((RHSB</^\Y0#&C^((RHSB:/^\Y0#&C^((RHSB8/^\Y0#&C^((
MRHSB6/^\Y0#&C^((RHSB4/^\Y0#&C^((RHSB2/^\Y0#&C^((RHSB0/^\Y0#&
MC^((RHSB./^\Y3!`+>ELPI_E+-!-XF@RG^4<`(WE&!"-Y10@C>4,P(_@`S"<
MYQ@0C>(4((WB'`"-XDA"G^4`,)/E)#"-Y0`PH./9___K."*?Y01`C^`"()3G
M,#*?Y0P@C>4#,)3G`A"@X0,`H.$0,(WE'PT`ZQ@RG^4#,)3G`##3Y0``4^-3
M```*<"\=[@0RG^4<$)WE`S"?YP0`@>(#()+G!P%PX\XSTN4#,(/CSC/"Y68`
M`(H``:#A`U"!XJ3__^L`,*#AT!&?Y=`AG^4!$(_@`$"1Y0(@C^`8$)WEP,&?
MY<`!G^4$,(+E'""=Y0#@D>4,P(_@``"/X`$`4N,$P(/E"$"#Y0#@@^4,`(/E
M5@``V@3@0>(,`(/B`N&.X`3`L>4!`%[A!,"@Y?O__QH#P(+B`."@XW!!G^5P
M$9_E!$"/X`P`E.4,X8/G!2"@X0$0C^``X(WE"?__ZP``4.,L```*3$&?Y01`
MC^`,`)3E3O__ZP!0H.$\`9_E(!"-X@``C^`,$(WEK0``ZP``4.,,$)WE(@``
M"B`QG^4#,(_@#`"3Y>?^_^LB___K$"&?Y=`PG^4"((_@`S"2YP`@D^4D,)WE
M`B`SX``PH.,K```:!0"@X2S0C>(P@+WH##"-Y?_^_^O<()_E``!0XP(@C^`,
M`(+E'P``"A3__^MP+QWNQ!"?Y0PPG>4!$)_G`1"2YW8VP>6=___J#`"4Y>'^
M_^O/___J"`"4Y0``4.,!```*=P@`Z]?__^J0`)_E``"/X'\``.L``%#C"`"$
MY='__PKV___J>#"?Y7@`G^4#,)3G``"/X`,0H.$,,(WE,___ZP3`H..N___J
M`0"@XUG__^L<___K&(X``!P!``#LC0``_````!0!```D`0``M(X``.B.``#H
MC@``S#<``,PW``"`C@``8`D``%B.``#D-```)(X``(R,``#4C0``1(T``,0S
M```H`0``H#4```"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1R@G^48,(_B`Z"*
MX``PH.,$,"WE#`"?Y0``FN<K___KCO[_ZS"+```P`0``%#"?Y10@G^4#,(_@
M`B"3YP``4N,>_R\!E/[_ZAB+`````0``+`"?Y2PPG^4L()_E``"/X`,PC^``
M`%/A`B"/X![_+P$8,)_E`S"2YP``4^,>_R\!$_\OX6R,``!HC```Y(H```0!
M```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.$H()_E0Q&!X,$0L.$"((_@'O\O
M`1@PG^4#,)+G``!3XQ[_+P$3_R_A+(P``"B,``"4B@``"`$``$PPG^5,()_E
M`S"/X``PT^4"((_@``!3XQ[_+Q$00"WI-#"?Y0,PDN<``%/C`@``"B@PG^4#
M`)_G^O[_Z\K__^L!(*#C&#"?Y0,PC^``(,/E$("]Z-R+``!8B@``+`$``&R+
M``"<BP``T/__ZO!'+>F\,)_EO""?Y0,PC^`"()/G`("2Y0``6.,G```*`%#0
MY0``5>,]`%43`5"@$P!0H`,3```:`$"8Y0``5.,.```*`9"@X0!PH.$(8*#A
M!2"@X0<0H.$$`*#AN/[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S
M__\:!`"@X?"'O>@`4*#A`3#UY0``4^,]`%,3^___&@!01>#D___J"&!&X`%0
MA>)&8:#A!4"$X`0`H.$`8(GE\(>]Z`A`H.'M___J\(D``!@!```00"WIC""?
MY8PPG^4"((_@<-!-X@,PDN<-$*#A`$"@X0`PD^5L,(WE`#"@XWC^_^L``%#C
M``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`
M()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@XP0`H.$=_O_K$`]OX:`"
MH.'N___J4O[_ZR")```<`0``U(@``'!`+>ET(9_E=#&?Y0(@C^`#,)+G@-!-
MX@!04.(`,)/E?#"-Y0`PH.,"```*`##5Y0``4^,*```:2"&?Y4`QG^4"((_@
M`S"2YP`@D^5\,)WE`B`SX``PH.-'```:@-"-XG"`O>C/_?_K`$!0XO'__PH$
M`*#A3_[_ZP``4.,P```*$R#0Y1,P@.(N`%+C`@``&@$@T^4``%+C]/__"A,@
MT.4N`%+C*P``"@4`H.$(,(WE^_W_ZP@PG>4`8*#A`P"@X0PPC>7V_?_K`""&
MX`(@@N("`*#A"""-Y17^_^L`8*#A##"=Y0(0H.,$,(WEF#"?Y0@@G>4#,(_@
M`%"-Y3#^_^L&`*#A$!"-XM;]_^L!`'#C!@"@X0,```H@,)WE#SH#X@$)4^,2
M```*X/W_ZP8`H.'#_?_K!`"@X1[^_^L``%#CSO__&@0`H.'M_?_K!0"@X0/^
M_^NW___J`2#3Y2X`4N/0__\:`B#3Y0``4N.___\*S/__ZJ'__^OK___J[_W_
MZWR(```<`0``2(@``/0N``#P0RWI`4"@X20BG^4D,I_E`B"/X`,PDN<4T$WB
M`#"3Y0PPC>4`,*#C`##1Y0!0H.$]`%/C`4"!`@0`H.&T_?_K"!"-X@!@H.$%
M`*#A*O__Z^1QG^4`@%#B!W"/X$(```JK_?_K``!6X3D``)K,,9_E"""=Y0-P
ME^<"(:#A``#5Y0``4.,]`%`3`0"@$P``H`,%```*!0"@X0$P\.4``%/C/0!3
M$_O__QH%`$#@`F"&X@``AN``((WE`&"7Y;C]_^L`()WE``!0XP(`AN<5```*
M`##5Y0`0E^4]`%/C``!3$P(0D><`,,'E!P``"@$`A>(!(('B`3#0Y`(0H.$`
M`%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E^___&A0A
MG^4$,9_E`B"/X`,PDN<`()/E##"=Y0(@,^``,*#C.```&A30C>+P@[WH`8!(
MX@$PU.0``%/C`3#HY?O__QKN___JS#"?Y0-PE^<`()?E`#"2Y0``4^,G```*
M`C"@X000L^4(`*#A``!1XP&`B.+Z__\:`P"`X@`QH.&<$)_E`1"/X```D>4`
M`%#C$@``&@$`H.,``('E`P"@X00@C>4`,(WE=/W_ZP"04.+3__\*""&@X0`P
MG>4$$)WE`""-Y9K]_^L`()WE`)"'Y0`PH.,!@(CB"#&)YYW__^H#$*#A`@"@
MX93]_^L`D%#B``"'Y<+__PH((:#A\___Z@.`H.$(,*#CW/__ZE[]_^OHA@``
M'`$``*"&```8`0``R(4``-"&``#P0"WI`7"@X?P0G^4!VDWB^#"?Y1303>(!
M$(_@`S"1YP!@H.$!"HWB`#"3Y0PP@.4`,*#C#`"`XM0`G^7_+P#C#!"-X@``
MC^!@_?_K`#!0X@8``-H!($/B`D"-X`P0U.4``%'C%P``&@``4N,4```:<`\=
M[IPPG^4'(*#A`S"?YP80H.$#`)#GZOS_ZX@@G^5X,)_E`B"/X`$:C>(#,)+G
M#!"!X@`@D^4`,)'E`B`SX``PH.,3```:`=J-XA30C>+P@+WH`C"@X0,@H.$O
M$*#C#`"-X@0PC>57_?_K``!0X^+__PIPSQWN,`"?Y080H.$``)_G!#"=Y0``
MG.<,((WB_/S_Z^#__^H5_?_KE(0``!P!``#0*P``/(4``!B$``#(A```$$`M
MZ7!/'>YH()_E:!"?Y0(@C^`!()+G$-!-XEP`G^4,((WE``"?YU0PG^54$)_E
M``"4YP,PC^`!$(_@)OW_ZP#`H.-``)_E0#"?Y0``G^<\()_E/!"?Y0,PC^``
M`)3G`B"/X`@0C>@!$(_@QOS_ZQ#0C>(0@+WH>(,``!`!``!PA```=&L``,@J
M``!(A```K"T``#06``"T*@``<`\=[C0@G^4TP)_E`B"/X`P@DN<(T$WB*!"?
MY00@C>4!$)_G(#"?Y0$`D.<<$)_E`S"/X`$0C^`(T(WB__S_ZN""```0`0``
MV(,``-QJ```P*@``<$`MZ>`@G^4"VDWBW#"?Y2#03>("((_@`S"2YP(:C>(<
M$('B`#"3Y0`P@>4`,*#CV_S_Z[C`G^6X,)_E#,"/X`$0C>@!(`'C`A"@XP,P
MC^`4`(WBWOS_ZP$:C>(!*J#C%`"-XA@0@>+3_/_K`$!0X@!0H+,,``"Z`3"$
MX@,`H.$,,(WEKOS_ZP!04.(&```*`1J-X@PPG>4$(*#A&!"!XG?\_^L`,*#C
M!##%YT@@G^4X,)_E`B"/X`(:C>(#,)+G'!"!X@`@D^4`,)'E`B`SX``PH.,#
M```:!0"@X0+:C>(@T(WB<("]Z)C\_^N$@@``'`$``!0J``#X*0``Y($``+[_
M_^KP3RWI/"*?Y4+=3>(X,I_E!-!-X@(@C^``4*#A+`*?Y0,PDN=!S8WB`7"@
MX0``C^`0$(WB/,",X@`PD^4`,(SE`#"@X]/]_^LO$*#C`$"@X04`H.$E_/_K
M``!0XQ(```KL`9_E!1"@X0``C^"*_O_K!0"@X=PAG^7,,9_E`B"/X$$=C>(#
M,)+G/!"!X@`@D^4`,)'E`B`SX``PH.-H```:0MV-X@30C>+PC[WH!P"@X5G\
M_^N@$9_E`1"/X&C\_^L`D%#BY?__"@`PV>6,L9_E``!3XPNPC^`I```*``!4
MXP0```H)$*#A!`"@X8_\_^L``%#C&0``"@D`H.$K_/_K`3!`X@,PB>`#`%GA
M`*"@X0$P@S(``*`S`1"),@,``#H(``#J`P!1X0``P^4"```*`2!SY2\`4N/Y
M__\*"0"@X1K\_^L`H*#A!0"@X1?\_^L*`(#@`@"`X@$*4.,5```Z_!"?Y0``
MH.,!$(_@//S_ZP"04.*Y__\*`##9Y0``4^/5__\:``!4XRD```H`,-3E+@!3
MXP,```K(D)_E`:"@XPF0C^#G___J`3#4Y0``4^/J__\*]___ZJP@G^4+,*#A
M`B"/X`(0H.,$((WE`)"-Y0$JH.,(4(WE?`"-XCO\_^L0$(WB?`"-XN'[_^L`
M`%#CVO__&B`PG>4/.@/B`@E3X];__QH!$*#C?`"-XM7[_^L``%#CT?__&E``
MG^5\$(WB``"/X!S^_^M\`(WB^OO_ZX___^HXD)_E`:"@XPF0C^#`___J`/S_
MZX"!```<`0``*"D``/@H```8@0``N"@``*`H```(*```L"<``+PG``!`)P``
M%"<``!!`+>DO$*#C`$"@X:C[_^L``%#C`4"`$@0`H.$00+WHW_O_ZA!`+>E\
M(9_E`=I-XG@QG^40T$WB`B"/X`$:C>(#,)+G#!"!X@`PD^4`,('E`#"@XP`0
M4.(Q```*`##1Y0``4^,N```*!!"-Y;'[_^L!((#B`0I2XSH``(H,0(WB!!"=
MY00`C>4$`*#AK_O_ZP0PG>4!,$/B`S"$X`0`4^$'``":`!"@XP(``.H!$$/D
M`P!4X0(```H`(-/E+P!2X_G__PHO$*#C!`"@X7C[_^L``%#C)0``"@0`4.$`
M,*"#`##`A00`H.&M^__KP""?Y;@PG^4"((_@`1J-X@,PDN<,$('B`""3Y0`P
MD>4"(#/@`#"@XR,``!H!VHWB$-"-XA"`O>B,()_E@#"?Y0(@C^`!&HWB`S"2
MYPP0@>(`()/E`#"1Y0(@,^``,*#C%0``&F0`G^4``(_@`=J-XA#0C>(00+WH
MCOO_Z@``H./>___J2""?Y30PG^4"((_@`1J-X@,PDN<,$('B`""3Y0`PD>4"
M(#/@`#"@XP(``!H@`)_E``"/X.O__^J)^__KY'X``!P!```H?@``\'T``(0E
M``"D?0``."4``'!`+>G`))_EP#2?Y0(@C^"\5)_E`S"2Y[ADG^4(T$WB!5"/
MX``PD^4$,(WE`#"@XP9@C^`-$*#A!@"@X<7\_^L``%#C#@``"HPTG^4`$)WE
M`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[
M__\:Z___ZE1DG^4&8(_@#1"@X08`H.&O_/_K``!0XPX```HT-)_E`!"=Y0,P
ME><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___
M&NO__^H`9)_E!F"/X`T0H.$&`*#AF?S_ZP``4.,.```*W#.?Y0`0G>4#,)7G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___JK&.?Y09@C^`-$*#A!@"@X8/\_^L``%#C#@``"H0SG^4`$)WE`S"5YP`@
MD^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___
MZEACG^4&8(_@#1"@X08`H.%M_/_K``!0XPX```HL,Y_E`!"=Y0,PE><`()/E
M`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H$
M8Y_E!F"/X`T0H.$&`*#A5_S_ZP``4.,.```*U#*?Y0`0G>4#,)7G`""3Y0$Q
M@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JL&*?
MY09@C^`-$*#A!@"@X4'\_^L``%#C#@``"GPRG^4`$)WE`S"5YP`@D^4!,8+@
M!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZEQBG^4&
M8(_@#1"@X08`H.$K_/_K``!0XPX```HD,I_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H(8I_E!F"/
MX`T0H.$&`*#A%?S_ZP``4.,.```*S#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JM&&?Y09@C^`-
M$*#A!@"@X?_[_^L``%#C#@``"G0QG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZF!AG^4&8(_@#1"@
MX08`H.'I^__K``!0XPX```H<,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H,`9_E#1"@X0``C^#4
M^__K`!!0X@(```KX`)_E``"/X)#\_^OP`)_E#1"@X0``C^#+^__K`!!0X@(`
M``K<`)_E``"/X(?\_^O4`)_E#1"@X0``C^#"^__K`!!0XA(```K``)_E``"/
MX'[\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8$)_E
MF`"?Y0$0C^```(_@"-"-XG!`O>AN_/_JA`"?Y0T0H.$``(_@J?O_ZP`04.+I
M__\*<`"?Y0``C^!E_/_KY?__ZD_Z_^M(?0``'`$``#1]```0)0``&`$``,0D
M``!T)```*"0``-@C``"0(P``U"(``.PB``"@(@``5"(``(`A``"L(0``@"$`
M`)PA``"<(0``F"$``+P@``#L>```="$``-@@``!$(0``R"````3@+>5X()_E
M>#"?Y0(@C^!T`)_E#-!-X@,PDN<-$*#A``"/X``PD^4$,(WE`#"@XWO[_^L`
M`%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WD%/K_ZQ1X```<`0``,"``
M`,1W```/`"WI!.`MY4@@G^5(,)_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C
M,`"?Y3#`G^44,(WB``"/X``PC>4,`)#G`A"@XQ`@G>4``)#EY_G_Z_\`H.,V
M^O_K?'<``!P!``!8=P``(`$```(0H./P1RWI>.&?Y0'83>)TP9_E&-!-X@[@
MC^`,P)[G`4B-X@`@H.,`,*#C`,"<Y13`A.4`P*#C`!"-Y0"`H.'?^?_K`0!0
MX@!PP>+'+Z#AQS\@X`(P4^!S,/_F`C`CX`(P4^`"(,+@`V!0X`)PQ^```%?C
M%$"$XC@``+H(D*#C#%"-X@&00.,`$*#C!B"@X0<PH.$(`*#A`!"-Y<CY_^L!
M`''C`0!P`S(```H)(*#A!1"@X0@`H.&+^?_K`0!PXRD```H'`%#C'P``F@@`
M0.(`0)7@'```*K"@G^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@
MX5/Y_^L``%#C]O__&@5`1.`&`)3@Q!^GX'@@G^5L,)_E`B"/X`'(C>(#,)+G
M%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!
M`'?C`0AV`\G__QH``.#C`!"@X>G__^HD`)_E``"/X(?__^L<`)_E``"/X(3_
M_^N4^?_K#'<``!P!``"$=P``"'8``'0>``!8'@``$$`MZ4KY_^MM^?_K``!0
MXP``D!40@+WH<$`MZ10AG^4409_E%#&?Y0(@C^`#,)+G(-!-X@1`C^``4*#A
M&!"-X@0`H.$`,)/E'#"-Y0`PH./,^O_K`#!0X@(```H`(-/E``!2XPX``!K4
M()_ES#"?Y0(@C^`#,)+G`""3Y1PPG>4"(#/@`#"@XRD``!H%$*#AL`"?Y0``
MC^`@T(WB<$"]Z'G[_^H%`*#A$#"-Y3OY_^L0,)WE`&"@X0,`H.$4,(WE-OG_
MZP`@AN`"((+B`@"@X1`@C>55^?_K%#"=Y6@0G^4(,(WE9#"?Y0$0C^`0()WE
M`S"/X`00C>4`4(WE`A"@XP!@H.%M^?_K1""?Y2PPG^4"((_@`S"2YP`@D^4<
M,)WE`B`SX``PH.,&$*`!!`"@`=C__PI`^?_K7'4``!P>```<`0``%'4``+P=
M``!X'```=!P``'1T``#P3RWIL!:?Y?303>*LQI_EK":?Y1@`C>4!$(_@`B"1
MYPS`C^`,,(SB&&",XHA`C>*@X(WB`""2Y>P@C>4`(*#C!P"3Z`<`A.@/`+;H
M#P"NZ`,`EN@PP(SBE%"-X@,`CN@'`)SH!P"%Z%@&G^4@<(WB!Q"@X0``C^!L
M^O_K2*:?Y0!@4.(*H(_@`@``"@`PUN4``%/C(`$`&L_X_^OR^/_K``!0XWL`
M``H`8)#E``!6XW@```H&`*#AXOC_ZX`@H.$!L(+B"P"@X0+Y_^L`P-;E`%"@
MX0``7.,+@*`1'`"-%1L!``KDE9_E"9"/X`L@H.$),*#A`A"@XP4`H.$`P(WE
M&/G_ZPL`6.$((*`A"R"@,0(P2^(+$$+@`<#VY0(P0^`"$('B`@!1X0&P@R`"
ML(,P``!<XP)0A>+K__\:D`6?Y:!@C>(``(_@`@``Z@0`MN4``%#C7P``"@<0
MH.$S^O_K`%!0XOC__PH`,-7E``!3X_7__PIA^O_K``!0X_+__PH%`*#AROC_
MZP!04.)1```*!0"@X:OX_^L<0)WE`&"@X00`H.&G^/_K`&"&X`%KAN($8(;B
M!@"@X<;X_^L`@*#A$#6?Y08@H.$#,(_@"#"-Y00UG^4"$*#C`S"/X`0PC>7X
M-)_E#$"-Y0,PC^``4(WEW/C_ZP<=H.,(`*#A2?C_ZP$`<.,#```:]/C_ZP``
MD.41`%#CM```&@<0H.$(`*#AN_C_ZP!`4.(U```*L`2?Y1@PG>4``)KGJ"2?
MY0`PD^4`@(WE`A"@XP``D.4"((_@IOC_ZP!0H..,))_E8#2?Y0(@C^`#,)+G
M`""3Y>PPG>4"(#/@`#"@XPL!`!H%`*#A]-"-XO"/O>B)^/_K`&!0XI$``!H$
M4(7B``"5Y0``4..M```*!Q"@X>#Y_^L`,%#B]___"@`PT^4``%/C]/__"O#_
M_^H%`*#A>?C_ZP!04.*N__\:!$"$X@!0E.4``%7CJO__"@`PU>4``%/C>```
M"@4`H.$!^O_K``!0X_3__PKO___J,#"=Y0\Z`^(!"5/CQ?__&CA0G>4O^/_K
M``!5X<'__QHP,)WE4S#HYP<-4^.]__\:!@"@X6;X_^L`4*#AJ`.?Y0<0H.$`
M`(_@M_G_ZP`04.**```*&#"=Y0``D^7,^__K`)!0XH4```H)`*#A-/C_ZP,`
M4.,`H*#A#```FFP3G^4$`$#B``")X`$0C^",^/_K``!0XP4``!H$`%KCL0``
M"@J@B>`%,%KE+P!3XZT```H\`Y_E!Q"@X0``C^":^?_K``!0XP,```H`,-#E
M,`!3XP``4Q,$```:"0"@X0`0H.,F^/_K`'!0XF<``!H$$Y_E!`.?Y0$0C^``
M`(_@2_K_ZTOX_^OT,I_E]"*?Y0,PC^`$,(WE[#*?Y0(@C^#HHI_EZ)*?Y>AR
MG^4(`(WE#""-Y0(0H.,&(*#A!0"@X0"`C>4#,(_@1OC_ZPJ@C^`)D(_@!W"/
MX`\``.I?^/_K`#"0Y1$`4^,0```:,?C_ZP#`H.$!0(3B`A"@XPHPH.$&(*#A
M!0"@X8`0C>D0D(WE#$"-Y0"`C>4R^/_K!QV@XP4`H.&?]__K`0!PX^K__PH(
M`*#AR_?_ZUP"G^4%$*#A``"/X!KZ_^L%`*#A>_[_ZV#__^H#4*#A+/__ZMGW
M_^N`(*#A`;""XO7^_^KP(9_E&#"=Y0+`FN<@(I_E`#"3Y00`C>4``)SE`A"@
MXP(@C^``@(WE]??_ZTW__^IG_O_K_"&?Y9@QG^4"((_@`S"2YP`@D^7L,)WE
M`B`SX``PH.-9```:!@"@X?30C>+P3[WHU_?_ZAP`C>7W_O_J#0"@X]SW_^L-
M@*#CN&&?Y5/`H.,`4*#A"+"@X09@C^`<`(WEU_[_ZA@PG>4`D)/E=O__ZMS]
M_^L`D%'B`*"@X9/__[H`L*#C"B!0X@`PR>('`*#A`+"-Y<3W_^NX$(WB!B"@
MXP<`H.$8$(WEB??_ZP8`4.,8$)WE-0``&D,\H..X()WE03-$XP,`4N&`__\:
M2#4$X[0@T>$#`%+A?/__&C(@6N(`,,GB!P"@X0"PC>7`0(WBK??_ZR@@H.,'
M`*#A!!"@X7/W_^LH`%#C(```&O@PG^7X$)_E`S"/X`0PC>7P,)_E`1"/X`P0
MC>4&(*#A`A"@XP4`H.$(0(WE`("-Y0,PC^#HL,WEO_?_ZY#__^H8,)WE!*"3
MY0``6N--__\*"@"@X7#W_^L#`%#C2?__FJ00G^4$`$#B``"*X`$0C^#)]__K
M``!0XPJ0H`%!___JC/?_ZX0`G^4``(_@>/W_ZQ1T``!(=0``'`$``'@;``"H
M<P``*!P``&0;``!<&P``/!H``#`;```@`0``'!L``,QQ``!T&@``.!H``*`8
M``#@&```8!@```08``",&@``K!D``+09``!8&@``P!<``"P7```@&```!&\`
M`)`7``#@%0``:!@``(07```T%P``(!<``'!`+>E4(I_E5#*?Y0(@C^`#,)+G
M"-!-X@`PD^4$,(WE`#"@XW!/'>XX,I_E.`*?Y0,PG^<-$*#A`U"4YP``C^!H
M,-7E:3#%Y:CX_^L``%#C`@``"@`PT.4Q`%/C90``"LS[_^L$,I_E`S"?YP-0
ME.?\$9_E!0"@X0,PH.,!(*#C`1"/X/7V_^L`4%#B#```"N`AG^40$)7E`B"?
MYP`0D>4"`)3GT"&?Y0(@C^#Q]O_K$#"5Y0`0D^4(,)'E`043XU<``!JT$9_E
M`S"@XP$0G^<!(*#C`0"4YZ01G^4!$(_@WO;_ZP!04.(+```*E`&?Y0T0H.$`
M`(_@?/C_ZQ`PE>4`(%#B`!"3Y3X```IX,9_E`S"?YP,`E.?6]O_K;#&?Y6P1
MG^4#,)_G`2"@XP-0E.<!$(_@!0"@X;GV_^M4(9_E`!"@X0(@C^`%`*#AR?;_
MZP`@H.-`,9_E0`&?Y0,PG^<-$*#A`S"4YP``C^!I(,/E7OC_ZRA1G^4``%#C
M!5"/X`!`H.$(`(7E$0``"@<=H.,$`*#AD_;_ZP$P@.(1`%#C`0!3$R0``(KX
M()_EL#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQH``!H(T(WB<("]Z`0`
ME>6X_?_K``!0XP!`H.$(`(7EY___&K@`G^4``(_@_/;_ZP$PT.4``%/CFO__
M"I7__^J@,)_E`0"@X0,PC^`$,)/E`!"3Y8?Y_^N]___JB#"?Y0,PG^<#`)3G
MTO;_ZZ+__^K9]O_K=!"?Y0`PH.$!$(_@;`"?Y000D>4$(*#A`!"1Y0``C^#B
M]O_KX&P``!P!``#(;0``Q!0``)!M``!4%@``8&T``#`6```L;0``!!8``,03
M``#H;```U&P``+05``"X%0``G&P``$03``#P;```/&L``!05``!<;```T&L`
M`"AL``#0%```$$`MZ1`AG^40,9_E`B"/X`!`H.$(`9_E$-!-X@,PDN<($(WB
M``"/X``PD^4,,(WE`#"@X_WW_^L``%#C"@``"@`PT.4P`%/C``!3$P$PH`,`
M,*`3`3`CX@``5.,`,*`#`3`#$@``4^,*```:M""?Y:@PG^4"((_@`S"2YP`@
MD^4,,)WE`B`SX``PH.,A```:$-"-XA"`O>@`,-3E``!3X_'__PH$`*#AH?K_
MZR\0H.,$`(WE0O;_ZP0PG>4``%#C`3"`$@,`H.%Y]O_K6!"?Y00@H.,!$(_@
MI?;_ZP``4./A__\:1""?Y3`PG^4"((_@`S"2YP`@D^4,,)WE`B`SX``PH.,#
M```:!`"@X1#0C>(00+WH(OC_ZG'V_^L@:@``'`$``#@2``"X:0``4!(``$!I
M````````\$\MZ7PLG^5\/)_E`B"/X`,PDN<`$*#AK=]-X@`PD^6L,HWE`#"@
MXP!0H.,H((WB0`"`XH!@@>($P!#E".`0Y2PTH.'_/`/B#$2@X2P\@^$(`(#B
M_T@$X@P\@^$^[[_F!#"#X0``5N$$4(+E`.""Y0@P@N4,4(+E$"""XNW__QJ@
M,)WE,+"=Y9!`G>4H4)WE-""=Y9B`G>4,,(WE%#"-Y2,^C>(+H*#A!""-Y1RP
MC>4D$(WE!7"@X02PH.$LD)WEI."=Y9Q@G>64()WE#!"=Y1"`C>4P`(WB"#"-
MY1A`C>4@4(WE`0``Z@6@H.$$0(WE`$"@XP$PH.$\P)#E.!"0Y0A0L.5T0(#E
M!$"0Y040(>`+$"'@!,`LX`<0(>`"P"S@"<`LX`BPH.$#@*#AH3^@X8PP@^$!
M$)'@`Q"!X0@PG>4&(*#A`P!0X0Y@H.$*<*#A`."@XP20G>5P$(#EX?__&IDI
M!^,D$)WE(%"=Y0C@D>4`8)'E##"1Y1"0D>48H)'E!`"1Y2[AH.&"*D7C('"1
MY0/OCN&FS:#A"#"1Y0J`*>"`PHSA`E"5X`/OCN$'4)7@'+"=Y0.`"."&PHSA
M)C&@X0J`*.`%P)S@`#^#X0X`*>`(<)S@!@``X`*PF^`)`"#@"K";X`8_@^$+
MP)#@.`"=Y0-0+N`"`)#@!U`%X`Y0)>`)`)#@Y\V,X`4`D.#L78#@0`"=Y1A`
MG>4"`)#@#@"0X&?A(^`,X`[@`^`NX&S!H.$.`)#@2."=Y6>!+.`"X)[@!8`(
MX&>!*.`#X)[@Y0V`X`C@GN#@C8[@4."=Y:$[#N,"X)[@9^&.X&5Q+.``<`?@
M#'`GX`?@GN!8<)WE8`&@X0)PE^`,P)?@97$@X`AP!^!E<2?@Z.V.X`?`G.#N
M?8S@8,"=Y=D^1N,"P)S@9<&,X&A1(.`.4`7@`%`EX`7`G.!H4)WE;N&@X0)0
ME>```)7@:%$NX`=0!>!H427@Y\V,X`4`D.#L78#@<`"=Y0(`D.!H`8#@9X$N
MX`R`".`.@"C@"`"0X.6-@.!X`)WE;,&@X0(`D.`.`)#@9^$LX`7@#N!GX2[@
M#@"0X.CM@."``)WE`@"0X&<!@.!E<2S@"'`'X`QP)^`'`)#@[GV`X(@`G>5H
M@:#A`@"0X`S`D.!E`2C@#@``X&4!(.```)S@`L"4X.=-@.!N`2C@!P``X&7!
MC.`(`"#@9W&@X0P`D.`0P)WEY%V`X&X!)^`"P)S@!```X`C`G.!N`2#@#`"0
MX!3`G>7E#8#@`L"<X&[AC.!DP2?@!<`,X`?`+.`.P)S@X.V,X*C`G>5E4:#A
M`L"<X`?`G.!D<27@`'`'X&1Q)^`'P)S@[GV,X+#`G>4"P)S@9,&,X&!!)>`.
M0`3@!4`DX`3`G."X0)WE;N&@X0)`E.`%0)3@8%$NX`=0!>!@427@!4"4X,!0
MG>7GS8S@`B"5X&`A@N!G`2[@#```X`X`(.``()+@R`"=Y>Q-A.`#`)#@;,&@
MX=!0G>4.`)#@9^$LX`3@+N#D+8+@#N"0X`,`E>!G`8#@V%"=Y>)]CN!DX2S@
M`N`NX`[@D.!B(:#A`P"5X`P`D.!DP2+@X("=Y0?`+.#G[8[@#,"0X.Y=C.`#
M`)C@9\$BX`[`+.!D`8#@Z$"=Y0P`D.!NP:#A\("=Y0/@E.!G02S@!4`DX`+@
MGN`$X)[@`T"8X.4-@.#X@)WE9T&$X&5Q+.``<"?@X.V.X`=`E.!@`:#A`W"8
MX`QPE^``@9WE[LV$X&5!(.`.0"3@!$"7X`-PF.!E<8?@"(&=Y6Y1(.`,4"7@
M[$V$X`5PE^!LP:#A`U"8X`!0E>`0@9WEY`V'X&YQ+.`$<"?@!U"5X-PL"^,#
M<)C@;G&'X!B!G>7@[87@9%$LX`!0)>`%4)?@8`&@X0-PF.`,<)?@((&=Y>[-
MA>!D42#@#E`EX`5PE^`#4)C@9%&%X"B!G>5N02#@#$`DX.Q]A^`$4)7@;,&@
MX0-`F.``0)3@,(&=Y><-A>!N42S@!U`EX`5`E.`#4)C@;N&%X#B!G>5G42S@
M`%`EX.!-A.`%X)[@8`&@X0-0F.`,P)7@0(&=Y6=1(.`$4"7@!5"<X`/`F.#D
M[8[@2(&=Y6?!C.!D<2#@#G`GX.Y=A>`'P)S@;N&@X0-PF.```)?@4(&=Y61Q
M+N`%<"?@!P"0X`-PF.#ES8S@6(&=Y61!A^!E<2[@#'`GX.P-@.`'0)3@;,&@
MX0-PF.`.<)?@8(&=Y67A+.``X"[@X$V$X`[@E^`#,)C@93&#X&B!G>7D78[@
M8.$LX!LO2.-D<:#A!.`NX`XPD^`"@)C@8.&'X6!!!^`,P)C@!>`.X'"!G>4$
MX([A#N"<X`+`F.#E/8/@8,&,X&4!A^%E00?@>(&=Y0,``.#C[8[@!`"`X6,Q
MH.%E08/A#,"0X`(`F.`'`)#@@(&=Y65Q`^`.0`3@!T"$X>[-C.``<)3@`D"8
MX&X!@^'L?8?@B(&=Y65!A.`,``#@;E$#X&S!H.$%`(#A;E&,X9"QG>4$`)#@
M!U`%X`)`F.!N@0S@`T"4X`A0A>$$4)7@`D";X.<-@.!N083@9^&,X6>!#."8
ML9WE`.`.X`C@CN'@787@!$">X&`!H.$"X)O@#.">X.7-A.!G08#A9X$`X*"Q
MG>4%0`3@"$"$X0Y`E.`"X)O@9W&.X&7A@.%E@0#@J+&=Y0S@#N`(X([A[$V$
MX`=PGN!LP:#A`N";X`#@GN#D#8?@97&,X66!#."PL9WE!'`'X`APA^$.X)?@
M`G";X&5QA^!D48SA9($,X+BQG>4`4`7@"%"%X>#MCN`'<)7@8`&@X0)0F^`,
M4)7@[LV'X&1Q@.%D@0#@P+&=Y0YP!^`(<(?A!5"7X`)PF^!D<8?@;D&`X6Z!
M`.#(L9WE#$`$X`A`A.'6,0SC[%V%X`=PE.!LP:#A`D";X`!`E.#E#8?@;G&,
MX6Z!#.#0L9WE!7`'X`APA^$$<)?@`D";X&Y!A.!EX8SA98$,X-BQG>4`X`[@
M".".X>!]A^`$X)[@8`&@X0)`F^`,P)3@94&`X>"QG>5E@0#@!T`$X`A`A.$,
M0)3@`L";X.?MCN!E48S@9\&`X6>!`.#HL9WE#L`,X`C`C.'N383@!5"<X&[A
MH.$"P)O@`,"<X.0-A>!G48[A9X$.X/"QG>4$4`7@"%"%X0Q0E>`"P)O@9W&,
MX&3!CN%D@0[@^+&=Y0#`#.`(P(SAX%V%X`?`G.!@`:#A`G";X`YPE^!DX8#A
M9($`X`"RG>4%X`[@".".X>7-C.`'X)[@`K";X&4A@.%E<0#@#"`"X`B"G>5D
M08O@!R""X6(Z3./L[8[@!""2X&S!H.'N38+@$'*=Y64A+.`#@)C@``"8X`X@
M(N`"()#@`P"7X&4!@.#D78+@`""@XQARG>4$(('E#""!Y10@@>4<(('E)""!
MY6XA+.`$("+@`B"0X&1!H.$#`)?@#`"0X.5]@N!NP23@("*=Y07`+.`,P)#@
M`P"2X&X!@.`H(IWE9>$DX`?@+N`.`)#@9^&@X0,@DN#GS8S@!""2X#!RG>5E
M02[@#$`DX`1`DN`#()?@[`V`X&QQ+N!E(8+@.%*=Y0!P)^#@383@!R"2X&`!
MH.$#4)7@;'$@X`[@E>!`4IWE!'`GX`?@GN`#4)7@Y"V"X&1Q(.!L487@2,*=
MY0)P)^#B[8[@!U"5X&(AH.$#P)S@9'$BX`#`G.#N#87@4%*=Y0YP)^`'P)S@
M`U"5X&YQ(N!D487@6$*=Y0!P)^#@S8S@!U"5X&`!H.$#0)3@8'*=Y0)`E.#L
M+87@;E$@X`Q0)>`%4)3@`T"7X&Y!A.!L<2#@:.*=Y0)P)^#B787@!T"4X&(A
MH.$#X)[@;'$BX`#@GN#E#83@<$*=Y05P)^`'X)[@`T"4X&5Q(N!LP83@X$V.
MX'CBG>4`<"?@!\"<X&`!H.$#X)[@@'*=Y0(@GN!EX2#@!.`NX`[@DN`#()?@
MY,V,X&1Q(.!E(8+@B%*=Y0QP)^#L[8[@!R"2X&S!H.$#4)7@9'$LX```E>"0
M4IWE#G`GX`<`D.`#4)7@[BV"X&1!A>!N<2S@F%*=Y0)P)^#B#8#@!T"4X&(A
MH.$#4)7@#%"5X&YQ(N"@PIWE`'`GX`=0E>`#,)S@X$V$X&"ABN`&,)/@8`$B
MX`0`(.!DD8G@;C&#X``PD^`8H('E$)"!Y0@`D>4@P)'EY%V%X```E>`,()+@
M(""!Y>4]@^`X()_E`#"!Y2PPG^4"((_@"`"!Y0,PDN<`()/EK#*=Y0(@,^``
M,*#C`0``&JW?C>+PC[WH2//_Z^AH```<`0``F%P``!!`+>F``*#C/_/_ZU`P
MC^+0(,/A`!"@X_`@P.%(,(_BT"##X?@@P.%$,(_BT"##X?`AP.%`,(_BT"##
MX?@AP.$\,(_BT"##X?`BP.$`(*#C`#"@XW@0@.7X(L#A\"/`X1"`O>@!(T5G
M`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````\$<MZ0)@H.$`
M,*#C`%"@X2C@D.4L`)#EAL&.X`X`7.$``-/@`7"@X3`@E>4T$)7EQ@^@X0$`
M`"H!()+B`!"AXBPPA>6F/J#A@#&#X0(PD^"@'J'@>`"5Y2C`A>4``%#C,#"%
MY300A>4XH(4")```&C\`5N,<``#:!T"@X2:#H.$!D$CB"(.'X`0PH.$*`*#A
M0""$X@!`D^4$X)/E","3Y0P0D^40,(/B`@!3X0!`@.4$X(#E","`Y0P0@.40
M`(#B\___&@-`H.$%`*#A@_S_ZP@`5.'K__\:0'"'XD!@1N()<X?@"9UIX`EC
MAN`&(*#A!Q"@X0H`H.'"\O_K>&"%Y?"'O>A`0&#B!@!4X09`H*$XH(7B!Q"@
MX00@H.$``(K@N/+_ZW@PE>4#,(3@0`!3XW@PA>7PA[T8!0"@X01@1N`$<(?@
M9?S_Z\C__^KP02WI`4"@X7\0X.,H,)3E,&"4Y3./O^;3,>7G`2"#XCAPA.(X
M`%+C`%"@X39OO^8#$,?G`@"'X#P``-H`$*#C0"!BXF_R_^L$`*#A4/S_ZS@@
MH.,`$*#C!P"@X6GR_^L$`*#A<&"$Y72`A.5(_/_K`S#4Y00`H.$`,,7ELC#4
MX0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E
M(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40
M,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,P
MU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>A$\O_J`!"@
MXS@@8N(R\O_KQ___Z@@PG^4#,(_@`#"3Y8KR_^I\6@``"$`MZ0B`O>@!``(`
M0`````D````P````"0````0````)````#`````D````_````"0```#<````)
M````%P````D````O````"0```!$````)````,P````D````5````"0```!(`
M```)````'P````D````V````"0```!`````)````)`````D````J````"0``
M````````````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C
M+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H`
M```E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`
M````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````;'-E96L@9F%I;&5D````
M`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````
M)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````
M+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!
M4CHZ4&%C:V5R.CI615)324].`````#$N,#8T````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M
M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<```
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P````!#04-(10``
M0`````D````P````"0````0````)````#`````D````_````"0```#<````)
M````%P````D````O````"0```!$````)````,P````D````5````"0```!(`
M```)````'P````D````V````"0```!`````)````)`````D````J````"0``
M````````````T(O_?P$`````````!````!`````!````1TY5```````#````
M`@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#$%```7!0```$````F`P```0```#8#```!````0`,`
M``P```"@#0``#0```)!%```9````O)T``!L````$````&@```,"=```<````
M!````/7^_V^T`0``!0```'P&```&````S`$```H```!T`P``"P```!`````5
M``````````,```#,G@```@```.`!```4````$0```!<```#`"P``$0```.@*
M```2````V````!,````(````'@````@```#[__]O`0``"/[__V^("@``____
M;P(```#P__]O\`D``/K__V\.````````````````````````````````````
M`````````````````````,2=`````````````*P-``"L#0``K`T``*P-``"L
M#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-
M``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T`
M`*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``
MK`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L
M#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T`````
M````````````````````````````````````````````````````````````
M``````"0$`````````2@```*4$%2+G!M"@````!T20``B$8```````!(1P``
M3$<``&A)``"01@``<$D```````!420``7$D```````!\20``1T-#.B`H36%G
M96EA(#$U+C$N,"TQ+FUG83$P*2`Q-2XQ+C``03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N
M;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````"P````<````"````=`$``'0!```D```````````````$`````````!X`
M```!`````@```)@!``"8`0``&0```````````````0`````````F````]O__
M;P(```"T`0``M`$``!@````$``````````0````$````,`````L````"````
MS`$``,P!``"P!```!0````,````$````$````#@````#`````@```'P&``!\
M!@``=`,``````````````0````````!`````____;P(```#P"0``\`D``)8`
M```$``````````(````"````30```/[__V\"````B`H``(@*``!@````!0``
M``(````$`````````%P````)`````@```.@*``#H"@``V`````0`````````
M!`````@```!E````"0```$(```#`"P``P`L``.`!```$````%0````0````(
M````;@````$````&````H`T``*`-```,```````````````$`````````&D`
M```!````!@```*P-``"L#0``Y`(`````````````!`````0```!T`````0``
M``8```"0$```D!`````U``````````````@`````````>@````$````&````
MD$4``)!%```(```````````````$`````````(`````!`````@```)A%``"8
M10``^$$`````````````!`````````"(`````0``<((```"0AP``D(<```@`
M```,``````````0`````````DP````$````"````F(<``)B'```$````````
M```````$`````````)T````'`````@```)R'``"<AP``(```````````````
M!`````````"K````#@````,```"\G0``O(T```0```````````````0````$
M````MP````\````#````P)T``,"-```$```````````````$````!````,,`
M```&`````P```,2=``#$C0``"`$```4`````````!`````@```#,`````0``
M``,```#,G@``S(X``#0!``````````````0````$````T0````$````#````
M`*````"0``!(```````````````$`````````-<````(`````P```$B@``!(
MD```%```````````````!`````````#<`````0```#``````````2)```"0`
M``````````````$````!````Y0````,``'```````````&R0```S````````
M```````!``````````$````#``````````````"?D```]0``````````````
(`0``````````
